# VirtualMachineResult

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project_id** | **str** |  | [optional] 
**id** | **str** |  | [optional] 
**data_center_id** | **str** |  | [optional] 
**gpu_model_id** | **str** |  | [optional] 
**gpus** | **int** |  | [optional] 
**vcpus** | **int** |  | [optional] 
**memory_gib** | **int** |  | [optional] 
**boot_disk_size_gib** | **int** |  | [optional] 
**boot_disk_public_image_id** | **str** |  | [optional] 
**boot_disk_private_image_id** | **str** |  | [optional] 
**state** | [**VmState**](VmState.md) |  | [optional] 
**create_time** | **datetime** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


